@@ -13,10 +13,10 @@ from os import path
 from sys import version_info
 import warnings
 import matplotlib
-# The native MacOSX backend doesn't work for all:
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore")
-    matplotlib.use('TkAgg')
+# # The native MacOSX backend doesn't work for all:
+# with warnings.catch_warnings():
+#     warnings.simplefilter("ignore")
+#     matplotlib.use('TkAgg')
 
 from .components import Component
 from . import dataset
@@ -26,9 +26,11 @@ from .lines import Line, show_transitions
 from . import hdf5_save
 from .hdf5_save import load_dataset, save_dataset
 from . import line_complexes
+from . import limits
 from . import molecules
 from . import output
 from . import regions
+from .regions import Region
 from . import voigt
 
 code_dir = path.dirname(path.abspath(__file__))
